function [LG, f, id, n_vertex] = LGT(A)

% function LGT transforms a graph G to a linegraph L(G). 
% 
% Input: 
%    A: Adjacency matrix
%    
% Output: 
%    LG: Adjacency matrix of the line graph (i.e., L(G))
%    f: edge weight as a function on the line graph
%    id: indices of non-zero elements in the adjacency matrix of G
%    n_vertex: number of vertices of L(G)
%    
% Note: It does not consider the special case of Y shaped graph. 
% 
% Code written by Won Hwa Kim, wonhwa@cs.wisc.edu
% Updated: June 24, 2013


N = length(A);
    
A_upper = zeros(N,N);
for r=1:N
    for c=1:r-1
        A_upper(r,c) = A(r,c);
    end
end

[id_low] = find(A_upper);
n_vertex = length(id_low);

label = zeros(N,N);
label(id_low) = 1:n_vertex;
label = label+label'; 

LG = zeros(n_vertex,n_vertex);

for k=1:N
    row = label(:,k);
    [idx1, idx2, val] = find(row);

    if(length(val) >= 2)
        pair = nchoosek(val,2);
        %pair = combntns(val,2);
        for l = 1:size(pair,1);
            LG(pair(l,1), pair(l,2)) = 1;   
        end
    end
end

LG = LG + LG';    
LG = sparse(LG);

cnt = 0;
for j=1:N
    for k=j+1:N
        if(A(j,k) ~= 0)
            cnt = cnt+1;
            f(cnt) = A(j,k);                
            id(cnt,1) = j;
            id(cnt,2) = k;
        end
    end
end
f = f';
