function WaCS = mbca_vectorize_WaCS(W)

% function mbca_vectorize_WaCS vertorizes a multi-scale WaCS.
% 
% Input: 
%    W: WaCS in cell arrays (n,s,N,N)
%       n: total number of instances (e.g., subjects)
%       s: total number of scales
%       N: total number of nodes in a graph
%    
% Output: 
%    WaCS: vectorized WaCS as matrix of n x s x (NxN)
%    
% Code written by Won Hwa Kim, won.kim@uta.edu
% Updated: May 29, 2018

n = size(W,1);
Nscales = size(W{1},1);
N = size(W{1}{1},1)*size(W{1}{1},2);

WaCS = zeros(N,Nscales,n);

for s=1:Nscales  
    for i=1:n
        WaCS(:,s,i) = W{i}{s}(:);       
    end    
end